#!/usr/bin/env python

# import gi
# from gi.repository import gtk, gtk.gdk
# from gi.repository import WebKit
# from gi.repository.gtk.gdkPixbuf import Pixbuf
import gtk

import sys
import commands
import os
import gettext
from user import home
import string

# i18n
gettext.install("cdos-welcome", "/usr/share/cdos-welcome/locale")

import signal
signal.signal(signal.SIGINT, signal.SIG_DFL)

class cdosWelcome():
    def __init__(self):
        window = gtk.Window()
        window.set_title(_("Welcome Screen"))
        window.set_icon_from_file("/usr/share/cdos-welcome/icons/logo.svg")
        window.set_position(gtk.WIN_POS_CENTER)
        window.connect("destroy", gtk.main_quit)
        window.modify_bg(gtk.STATE_NORMAL,gtk.gdk.Color('#f7f7f7'))

        sys.path.append('/usr/share/cdos-welcome')
        from configobj import ConfigObj
        config = ConfigObj("/etc/lsb-release")
        #codename = config['CODENAME'].capitalize()
        #edition = config['EDITION']
        #release = config['RELEASE']
        #desktop = config['DESKTOP']
        grub_title = config['DISTRIB_DESCRIPTION']
         
        main_box = gtk.VBox() 

        event_box = gtk.EventBox()
        event_box.set_name("event_box")
 
        event_box.modify_bg(gtk.STATE_NORMAL,gtk.gdk.Color('#ffffff'))
        main_box.pack_start(event_box, False, False, 0)


        event_box1 = gtk.EventBox()
        event_box1.set_name("event_box1")
 
        event_box1.modify_bg(gtk.STATE_NORMAL,gtk.gdk.Color('#dbdbdb'))
        event_box1.set_border_width(1)
        main_box.pack_start(event_box1, False, False, 0)
        

        vbox = gtk.VBox()
        vbox.set_border_width(0)
        vbox.set_spacing(0)
        event_box.add(vbox)   

        vbox1 = gtk.VBox()
        vbox1.set_spacing(0) 
        main_box.pack_start(vbox1, False, False, 0)
        headerbox = gtk.VBox()
        space1 = gtk.VBox()
        headerbox.pack_start(space1, False, False, 26)
        logo = gtk.Image()
        logo.set_from_file("/usr/share/cdos-welcome/icons/logo.png")
        headerbox.pack_start(logo, False, False, 0) 
        
        space2 = gtk.VBox()
        headerbox.pack_start(space2, False, False, 6)
        label = gtk.Label()
        label.set_markup("<span font='13' fgcolor='#333333'>%s</span>" % grub_title)
        headerbox.pack_start(label, False, False, 0)
        #label = gtk.Label()
        #label.set_markup("<span font='8' fgcolor='#3e3e3e'><i>%s</i></span>" % edition)
        #headerbox.pack_start(label, False, False, 2)
        vbox.pack_start(headerbox, False, False, 0)

        welcome_label = gtk.Label()
        welcome_message = _("Welcome and thank you for choosing CDOS. We hope you'll enjoy using it as much as we did designing it. The links below will help you get started with your new operating system. Have a great time and don't hesitate to send us your feedback.")
        welcome_label.set_width_chars(88)
        # welcome_label.set_single_line_mode(False)
        welcome_label.set_markup("<span font='11' fgcolor='#777777'>%s</span>" % welcome_message)
        welcome_label.set_line_wrap(True)
        vbox.pack_start(welcome_label, False, False, 35)


        liststore = gtk.ListStore(gtk.gdk.Pixbuf, str, str, str)
        iconview = gtk.IconView()
        iconview.set_model(liststore)
        iconview.set_pixbuf_column(0)
        iconview.set_markup_column(2)
        iconview.set_tooltip_column(3)
        iconview.set_columns(3)
        iconview.set_spacing(6)
        iconview.set_item_padding(4)
        iconview.set_row_spacing(38)
        iconview.set_column_spacing(100)
        iconview.connect("item-activated", self.item_activated)     
        iconview.modify_base(gtk.STATE_NORMAL,gtk.gdk.Color('#f7f7f7'))
        hbox = gtk.HBox()
        align = gtk.Alignment()	
        align.set(0.9,0,0,0)
        align.add(hbox)
        hbox.add(iconview)
        vbox1.pack_start(align, True, True, 30)

        actions = []
        actions.append(['new_features', "<span font='10' fgcolor='#333333'>%s</span>" %_("New features"), _("See what is new in this release")])
        actions.append(['online_intro', "<span font='10' fgcolor='#333333'>%s</span>" %_("Online intro"), _("Learn all the basics to get started with CDOS")])
        actions.append(['feedback', "<span font='10' fgcolor='#333333'>%s</span>" %_("Feedback"), _("Feedback and suggestions for us")])
        actions.append(['cs-details', "<span font='10' fgcolor='#333333'>%s</span>" %_("System Info"), _("View system details")])
        actions.append(['cdos_update', "<span font='10' fgcolor='#333333'>%s</span>" %_("System update"), _("Check for updates to enhance computer security and efficiency")])
        actions.append(['cdos_settings', "<span font='10' fgcolor='#333333'>%s</span>" %_("System settings"), _("System control center")])

        for action in actions:
            pixbuf = gtk.gdk.pixbuf_new_from_file('/usr/share/cdos-welcome/icons/%s.png' % action[0])
            liststore.append([pixbuf, action[0], action[1], action[2]])
               
        window.add(main_box)
        window.set_size_request(695, 581)
        window.set_resizable(False) 


        window.show_all()

    def on_button_toggled(self, button):
        if button.get_active():
            if os.path.exists(home + "/.cdos/cdos-welcome/norun.flag"):
                os.system("rm -rf " + home + "/.cdos/cdos-welcome/norun.flag")
        else:  
            os.system("mkdir -p " + home + "/.cdos/cdos-welcome")
            os.system("touch " + home + "/.cdos/cdos-welcome/norun.flag")

    def item_activated(self, view, path):
        if (len(path)>0):
            treeiter = view.get_model().get_iter(path[0])
            value = view.get_model().get_value(treeiter, 1)
            print(value)
            if value == "new_features": 
                os.system("xdg-open /usr/share/cdos-welcome/features-html/features-index.html &")
            elif value == "online_intro":
            	os.system("xdg-open /usr/share/nfs/html/help.htm &")
            elif value == "feedback":
                if os.path.exists("/usr/bin/cdosfeedback"):
                    os.system("/usr/bin/cdosfeedback &")
            elif value == "cs-details":
                if os.path.exists("/usr/bin/cdos-settings"):
                    os.system("/usr/bin/cdos-settings info &")
            elif value == "cdos_update":
                if os.path.exists("/usr/bin/cdosupdate-launcher"):
                    os.system("/usr/bin/cdosupdate-launcher --show &")
            elif value == "cdos_settings":
                if os.path.exists("/usr/bin/cdos-settings"):
                    os.system("/usr/bin/cdos-settings &")
 

if __name__ == "__main__":
    cdosWelcome()
    gtk.main()
